.. _kinematics:

=======================
Kinematics (Docstrings)
=======================

Point
=====

.. automodule:: sympy.physics.vector.point
   :members:


kinematic_equations
===================

.. automodule:: sympy.physics.vector.functions
   :members: kinematic_equations, partial_velocity, get_motion_params
